# !/usr/bin/python
# -*- coding: utf-8 -*-


from setuptools import find_packages, setup

setup(
    name="piotr1000200030004455",
    version="0.0.1",
    author="Uczeń SDA",
    author_email="young@termal.com",
    packages=find_packages(),
    include_package_data=True,
    description="Testing library"
)

